<?php
namespace BackOfficeOptimizer\Services;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class ServiceSettings{
    protected $connection;
    protected $newCode;

    public function __construct($connection, $newCode){
        $this->connection = $connection;
        $this->newCode = $newCode;
    }    

    public function updateServConfig($parameters){
        $toAdd = [];
        $toRemove = [];

        foreach ($parameters['toSaveData'] as $key => $reg) {
            if($reg['operation']=='add'){
                $toAdd[] = $reg['data'];
            } else {
                $toRemove[] = $reg['data'];
            }
        }

        $this->addNewRegisters($toAdd, $parameters['boData']);
        $this->removeRegisters($toRemove, $parameters['boData']);
    }

    public function addNewRegisters($toAdd, $boData){
        $insertSql = "INSERT INTO CONFCARDGRUPOPRATO(NRCONFCARDGRUPOPRATO, CDFILIAL, CDSERVFILI, NRSEQCNFCARD, NRGRUPOPRATOSERV, NRORG)
        VALUES(:NRCONFCARDGRUPOPRATO, :CDFILIAL, :CDSERVFILI, :NRSEQCNFCARD, :NRGRUPOPRATOSERV, :NRORG)";

        $params = [
            'CDFILIAL'=>$boData['unit'],
            'CDSERVFILI'=>$boData['service'],
            'NRORG'=>$boData['nrorg']
        ];

        $statement = $this->connection->prepare($insertSql);
        
        foreach ($toAdd as $reg) {
            $params['NRCONFCARDGRUPOPRATO'] = $this->newCode->getCodeByTableName('CONFCARDGRUPOPRATO', $boData["nrorg"]);
            $params['NRSEQCNFCARD'] = $reg['NRSEQCNFCARD'];
            $params['NRGRUPOPRATOSERV'] = $reg['NRGRUPOPRATOSERV'];
            $statement->execute($params);
        }
    }

    public function removeRegisters($toRemove, $boData){
        $insertSql = "DELETE FROM CONFCARDGRUPOPRATO WHERE 
        CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND NRSEQCNFCARD = :NRSEQCNFCARD AND
        NRGRUPOPRATOSERV = :NRGRUPOPRATOSERV AND NRORG = :NRORG";

        $params = [
            'CDFILIAL'=>$boData['unit'],
            'CDSERVFILI'=>$boData['service'],
            'NRORG'=>$boData['nrorg']
        ];

        $statement = $this->connection->prepare($insertSql);

        foreach ($toRemove as $reg) {
            $params['NRSEQCNFCARD'] = $reg['NRSEQCNFCARD'];
            $params['NRGRUPOPRATOSERV'] = $reg['NRGRUPOPRATOSERV'];
            $statement->execute($params);
        }
    }

    public function updateServConfigPercentualSource($params){
        $insertSql = "UPDATE CONFCARD SET IDUTILPERCENTCONS = :IDUTILPERCENTCONS WHERE 
        CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND NRSEQCNFCARD = :NRSEQCNFCARD AND NRORG = :NRORG";

        $args = [
            'IDUTILPERCENTCONS' => $params['toSaveData']['IDUTILPERCENTCONS'],
            'CDFILIAL' => $params['toSaveData']['CDFILIAL'],
            'CDSERVFILI' => $params['toSaveData']['CDSERVFILI'],
            'NRSEQCNFCARD' => $params['toSaveData']['NRSEQCNFCARD'],
            'NRORG' => $params['toSaveData']['NRORG']
        ];

        $statement = $this->connection->prepare($insertSql);
        $statement->execute($args);
    }
    
    public function updateServConfigFixedColumn($params){
        $insertSql = "UPDATE CONFCARD SET IDOTMCOLUNAFIXA = :IDOTMCOLUNAFIXA WHERE 
        CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND NRSEQCNFCARD = :NRSEQCNFCARD AND NRORG = :NRORG";

        $args = [
            'IDOTMCOLUNAFIXA' => $params['toSaveData']['IDOTMCOLUNAFIXA'],
            'CDFILIAL' => $params['toSaveData']['CDFILIAL'],
            'CDSERVFILI' => $params['toSaveData']['CDSERVFILI'],
            'NRSEQCNFCARD' => $params['toSaveData']['NRSEQCNFCARD'],
            'NRORG' => $params['toSaveData']['NRORG']
        ];
        $statement = $this->connection->prepare($insertSql);
        $statement->execute($args);
    }
    
    public function updateServConfigNoColor($params){
        $insertSql = "UPDATE CONFCARD SET IDOTMNAOCONSCOR = :IDOTMNAOCONSCOR WHERE 
        CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND NRSEQCNFCARD = :NRSEQCNFCARD AND NRORG = :NRORG";

        $args = [
            'IDOTMNAOCONSCOR' => $params['toSaveData']['IDOTMNAOCONSCOR'],
            'CDFILIAL' => $params['toSaveData']['CDFILIAL'],
            'CDSERVFILI' => $params['toSaveData']['CDSERVFILI'],
            'NRSEQCNFCARD' => $params['toSaveData']['NRSEQCNFCARD'],
            'NRORG' => $params['toSaveData']['NRORG']
        ];
        $statement = $this->connection->prepare($insertSql);
        $statement->execute($args);
    }
    
    public function updateServConfigNoPreparationMode($params){
        $insertSql = "UPDATE CONFCARD SET IDOTMNAOCONSMOD = :IDOTMNAOCONSMOD WHERE 
        CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND NRSEQCNFCARD = :NRSEQCNFCARD AND NRORG = :NRORG";

        $args = [
            'IDOTMNAOCONSMOD' => $params['toSaveData']['IDOTMNAOCONSMOD'],
            'CDFILIAL' => $params['toSaveData']['CDFILIAL'],
            'CDSERVFILI' => $params['toSaveData']['CDSERVFILI'],
            'NRSEQCNFCARD' => $params['toSaveData']['NRSEQCNFCARD'],
            'NRORG' => $params['toSaveData']['NRORG']
        ];
        $statement = $this->connection->prepare($insertSql);
        $statement->execute($args);
    }
    
    public function updateServConfigInterleaveDishes($params){
        var_dump($params);
        $insertSql = "UPDATE CONFCARD SET IDOTMINTERCPRAT = :IDOTMINTERCPRAT  WHERE 
        CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND NRSEQCNFCARD = :NRSEQCNFCARD AND NRORG = :NRORG";

        $args = [
            'IDOTMINTERCPRAT' => $params['toSaveData']['IDOTMINTERCPRAT'],
            'CDFILIAL' => $params['toSaveData']['CDFILIAL'],
            'CDSERVFILI' => $params['toSaveData']['CDSERVFILI'],
            'NRSEQCNFCARD' => $params['toSaveData']['NRSEQCNFCARD'],
            'NRORG' => $params['toSaveData']['NRORG']
        ];
        $statement = $this->connection->prepare($insertSql);
        $statement->execute($args);
    }
}
